# Installing the required packages for the tutorials. 
# This is only required once. 
# Uncomment the code below to run the install.packages function.
# install.packages(c("eRm", "dplyr", "ggplot2", "pairwise", "TAM", "psych"))

# Load the packages required for the analysis
library(eRm)
library(dplyr)

# Reading in the comma-seperated data set
df <- read.csv("ARMChapter5.csv", header = FALSE, sep = ";") 

# Defining the name of the first column of the data frame called "df"
colnames(df)[1] <- c("group") 
colnames(df)[2] <- c("gender") 
# Defining the names of the columns referring to the items
colnames(df)[3:37] <- paste("Blot", (1:35), sep="_") 
# Selecting only the BLOT items
blot_items <- dplyr::select(df, Blot_1:Blot_35) 
# Looking at the first five rows of the blot dataframe
head(blot_items)

# Fit a Rasch model for the BLOT data
fit_rasch_blot <- RM(blot_items)
# Perform the Likelihood Ratio test based on the group variable
(lrtest <- LRtest(fit_rasch_blot, splitcr = df$group))

plotGOF(lrtest, col = "black", tlab = "number", 
        main = "Invariance Check BLOT: Item Parameters High vs Low Scorers", 
        xlab = "Item parameters of high scorers", ylab = "Item parameters of low scorers",  
        xlim = c(-3, 3), ylim = c(-3, 3), pos = 1, 
        smooline = list(gamma = .95, col = "black", lty = "dashed"))

# Estimates Rasch model parameters for high scorers 
fit_rasch_blot_high <- eRm::RM(blot_items[which(df$group == "H"), ])


# Estimates Rasch model parameters for low scorers
fit_rasch_blot_low <- eRm::RM(blot_items[which(df$group == "L"), ])

# Item fit statistics for low scorers
pp_low <- person.parameter(fit_rasch_blot_low)
item_fit_low <- itemfit(pp_low)
print(item_fit_low)

# Item fit statistics for high scorers
pp_high <- person.parameter(fit_rasch_blot_high)
item_fit_high <- itemfit(pp_high)
print(item_fit_high)


# This code plots the boys' and girls' ICCs next to each other
# Boys are in blue, girls are in red
par(mfrow=c(1,2))
sapply(1:35, function(x){
  plotICC(RM(blot_items[which(df$gender == "G"), ]), empICC = list("raw", type = "b", col = "red", lty = "dotted"), item.subset = x, cex.main=.7)
  plotICC(RM(blot_items[which(df$gender == "B"), ]), empICC = list("raw", type = "b", col = "blue", lty = "dotted"), item.subset = x, cex.main=.7)
})


# Uncomment the code below if you would like to plot all the boys together, and then all the girls together

# Actual vs theoretical ICC for boys:
# plotICC(RM(blot_items[which(df$gender == "B"), ]), empICC = list("raw", type = "b", col = "blue", lty = "dotted"))

# Actual vs theoretical ICC for girls:
# plotICC(RM(blot_items[which(df$gender == "G"), ]), empICC = list("raw", type = "b", col = "red", lty = "dotted"))
